@@ -132,16 +132,29 @@ class LinUnconditionalFrame(LinFrame):
                  as is (float and string values)
         """
         converted = {}
+
+        def default_encoder(_value, _signal):
+            if isinstance(_value, (int, list)):
+                return _value
+
+            raise ValueError(f'No encoding type found for {_signal} ({value})')
+
         for (signal_name, value) in data.items():
             signal = self._get_signal(signal_name)
+            encoder = default_encoder
             if encoding_types is not None and signal_name in encoding_types:
-                converted[signal_name] = encoding_types[signal_name].encode(value, signal)
+                encoder = encoding_types[signal_name].encode
             elif signal.encoding_type is not None:
-                converted[signal_name] = signal.encoding_type.encode(value, signal)
-            elif isinstance(value, int):
+                encoder = signal.encoding_type.encode
+
+            if signal.is_array():
+                if not isinstance(value, list):
+                    num_of_bytes = int(signal.width / 8)
+                    value = [b for b in int.to_bytes(encoder(value, signal), num_of_bytes, "big")]
                 converted[signal_name] = value
             else:
-                raise ValueError(f'No encoding type found for {signal_name} ({value})')
+                converted[signal_name] = encoder(value, signal)
+
         return self.encode_raw(converted)
 
     def _signal_map_to_message(self, signals: Dict[str, int]) -> List[int]:
@@ -206,16 +219,26 @@ class LinUnconditionalFrame(LinFrame):
             frame_layout = u6p2u8u1u1p6
 
         """
+        def default_decoder(_value, *args):
+            return _value
+
         parsed = self.decode_raw(data)
         converted = {}
         for (signal_name, value) in parsed.items():
             signal = self._get_signal(signal_name)
+            decoder = default_decoder
             if encoding_types is not None and signal_name in encoding_types:
-                converted[signal_name] = encoding_types[signal_name].decode(value, signal, keep_unit)
+                decoder = encoding_types[signal_name].decode
             elif signal.encoding_type is not None:
-                converted[signal_name] = signal.encoding_type.decode(value, signal, keep_unit)
+                decoder = signal.encoding_type.decode
+
+            if signal.is_array():
+                if decoder is not default_decoder:
+                    value = int.from_bytes(value, "big")
+                converted[signal_name] = decoder(value, signal, keep_unit)
             else:
-                converted[signal_name] = value
+                converted[signal_name] = decoder(value, signal, keep_unit)
+
         return converted
 
     def decode_raw(self,
